
RELEASE_VERSION='0.1.518638777'
BUILD_DATE='Mon Apr 18 06:05:08 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0jl7zk 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2344668697'
GIT_COMMIT_SHA='fa96ce91efe9221fe3189a6d031cc6460d87625f'
GIT_BRANCH='main'
